@@ -5,7 +5,7 @@ import os
 import socket as stdlib_socket
 import inspect
 import tempfile
-
+import sys as _sys
 from .._core.tests.tutil import creates_ipv6, binds_ipv6
 from .. import _core
 from .. import _socket as _tsocket
@@ -263,6 +263,29 @@ async def test_socket_v6():
         assert s.family == tsocket.AF_INET6
 
 
+@pytest.mark.skipif(not _sys.platform == "linux", reason="linux only")
+async def test_sniff_sockopts():
+    from socket import AF_INET, AF_INET6, SOCK_DGRAM, SOCK_STREAM
+    # generate the combinations of families/types we're testing:
+    sockets = []
+    for family in [AF_INET, AF_INET6]:
+        for type in [SOCK_DGRAM, SOCK_STREAM]:
+            sockets.append(stdlib_socket.socket(family, type))
+    for socket in sockets:
+        # regular Trio socket constructor
+        tsocket_socket = tsocket.socket(fileno=socket.fileno())
+        # check family / type for correctness:
+        assert tsocket_socket.family == socket.family
+        assert tsocket_socket.type == socket.type
+
+        # fromfd constructor
+        tsocket_from_fd = tsocket.fromfd(socket.fileno(), AF_INET, SOCK_STREAM)
+        # check family / type for correctness:
+        assert tsocket_from_fd.family == socket.family
+        assert tsocket_from_fd.type == socket.type
+        socket.close()
+
+
 ################################################################
 # _SocketType
 ################################################################
@@ -381,6 +404,17 @@ async def test_SocketType_simple_server(address, socket_type):
             assert await client.recv(1) == b"x"
 
 
+async def test_SocketType_is_readable():
+    a, b = tsocket.socketpair()
+    with a, b:
+        assert not a.is_readable()
+        await b.send(b"x")
+        await _core.wait_readable(a)
+        assert a.is_readable()
+        assert await a.recv(1) == b"x"
+        assert not a.is_readable()
+
+
 # On some macOS systems, getaddrinfo likes to return V4-mapped addresses even
 # when we *don't* pass AI_V4MAPPED.
 # https://github.com/python-trio/trio/issues/580
@@ -448,6 +482,7 @@ async def test_SocketType_resolve(socket_type, addrs):
         async def res(*args):
             return await getattr(sock, resolver)(*args)
 
+        # yapf: disable
         assert await res((addrs.arbitrary,
                           "http")) == (addrs.arbitrary, 80, *addrs.extra)
         if v6:
@@ -462,6 +497,7 @@ async def test_SocketType_resolve(socket_type, addrs):
         # Check the <broadcast> special case, because why not
         assert await res(("<broadcast>",
                           123)) == (addrs.broadcast, 123, *addrs.extra)
+        # yapf: enable
 
         # But not if it's true (at least on systems where getaddrinfo works
         # correctly)
@@ -595,18 +631,16 @@ async def test_SocketType_non_blocking_paths():
 # This tests the complicated paths through connect
 async def test_SocketType_connect_paths():
     with tsocket.socket() as sock:
-        with assert_checkpoints():
-            with pytest.raises(ValueError):
-                # Should be a tuple
-                await sock.connect("localhost")
+        with pytest.raises(ValueError):
+            # Should be a tuple
+            await sock.connect("localhost")
 
     # cancelled before we start
     with tsocket.socket() as sock:
-        with assert_checkpoints():
-            with _core.CancelScope() as cancel_scope:
-                cancel_scope.cancel()
-                with pytest.raises(_core.Cancelled):
-                    await sock.connect(("127.0.0.1", 80))
+        with _core.CancelScope() as cancel_scope:
+            cancel_scope.cancel()
+            with pytest.raises(_core.Cancelled):
+                await sock.connect(("127.0.0.1", 80))
 
     # Cancelled in between the connect() call and the connect completing
     with _core.CancelScope() as cancel_scope:
@@ -637,16 +671,15 @@ async def test_SocketType_connect_paths():
 
     # Failed connect (hopefully after raising BlockingIOError)
     with tsocket.socket() as sock:
-        with assert_checkpoints():
-            with pytest.raises(OSError):
-                # TCP port 2 is not assigned. Pretty sure nothing will be
-                # listening there. (We used to bind a port and then *not* call
-                # listen() to ensure nothing was listening there, but it turns
-                # out on macOS if you do this it takes 30 seconds for the
-                # connect to fail. Really. Also if you use a non-routable
-                # address. This way fails instantly though. As long as nothing
-                # is listening on port 2.)
-                await sock.connect(("127.0.0.1", 2))
+        with pytest.raises(OSError):
+            # TCP port 2 is not assigned. Pretty sure nothing will be
+            # listening there. (We used to bind a port and then *not* call
+            # listen() to ensure nothing was listening there, but it turns
+            # out on macOS if you do this it takes 30 seconds for the
+            # connect to fail. Really. Also if you use a non-routable
+            # address. This way fails instantly though. As long as nothing
+            # is listening on port 2.)
+            await sock.connect(("127.0.0.1", 2))
 
 
 async def test_resolve_remote_address_exception_closes_socket():
@@ -822,7 +855,7 @@ async def test_custom_hostname_resolver(monkeygai):
     # We can set it back to None
     assert tsocket.set_custom_hostname_resolver(None) is cr
 
-    # And now trio switches back to calling socket.getaddrinfo (specifically
+    # And now Trio switches back to calling socket.getaddrinfo (specifically
     # our monkeypatched version of socket.getaddrinfo)
     monkeygai.set("x", b"host", "port", family=0, type=0, proto=0, flags=0)
     assert await tsocket.getaddrinfo("host", "port") == "x"
